@@ -16,13 +16,16 @@
 #' @param n number of random values to be generated.
 #' @param rate the shape parameter, which must be a positive interval.
 #' @param lower.tail logical; if TRUE (default), probabilities are
-#' \eqn{P(X \ge x)}; otherwise, \eqn{P(X >x)}.
+#' \eqn{P(X \leq x)}; otherwise, \eqn{P(X >x)}.
 #'
 #' @return
-#'  \code{pnsexp} gives the distribution function,
-#'  \code{dnsexp} gives the density,
-#'  \code{qnsexp} gives the quantile function and
-#'  \code{rnsexp} generates random values from the neutrosophic exponential distribution.
+#'  \code{dnsExp} gives the density function
+#'
+#'  \code{pnsExp} gives the distribution function
+#'
+#'  \code{qnsExp} gives the quantile function
+#'
+#'  \code{rnsExp} generates random values from the neutrosophic exponential distribution.
 #'
 #' @references
 #' Duan, W., Q., Khan, Z., Gulistan, M., Khurshid, A. (2021). Neutrosophic
@@ -33,15 +36,16 @@
 #'
 #' @examples
 #' # Example 4 of Duan et al. (2021)
+#'
 #' data <- matrix(c(4, 4, 3.5, 3.5, 3.9, 4.1, 4.2, 4.2, 4.3, 4.6, 4.7, 4.7),
 #'  nrow = 6, ncol = 2, byrow = TRUE)
 #'
-#' dnsexp(data, rate = c(0.23, 0.24))
-#' dnsexp(x = c(4, 4.1), rate = c(0.23, 0.24))
+#' dnsExp(data, rate = c(0.23, 0.24))
+#' dnsExp(x = c(4, 4.1), rate = c(0.23, 0.24))
 #'
-#' dnsexp(4, rate = c(0.23, 0.23))
+#' dnsExp(4, rate = c(0.23, 0.23))
 #' @export
-dnsexp <- function(x, rate) {
+dnsExp <- function(x, rate) {
   if (any(rate <= 0) || any(x < 0)) {
     stop("Arguments are incompatible.")
   }
@@ -60,19 +64,17 @@ dnsexp <- function(x, rate) {
     pdf[, i] <- rate[i] * exp(-x[, i] * rate[i])
   }
 
-
-
   return(pdf)
 }
 #' @name Neutrosophic Exponential
 #' @examples
 #'
 #' # The cumulative distribution function for the nuetrosophic observation (4,4.1)
-#' pnsexp(c(4, 4.1), rate = c(0.23, 0.24), lower.tail = TRUE)
+#' pnsExp(c(4, 4.1), rate = c(0.23, 0.24), lower.tail = TRUE)
 #'
-#' pnsexp(4, rate = c(0.23, 0.24))
+#' pnsExp(4, rate = c(0.23, 0.24))
 #' @export
-pnsexp <- function(q, rate, lower.tail = TRUE) {
+pnsExp <- function(q, rate, lower.tail = TRUE) {
   if (any(rate <= 0) || any(q < 0)) {
     stop("Arguments are incompatible.")
   }
@@ -85,31 +87,28 @@ pnsexp <- function(q, rate, lower.tail = TRUE) {
     stop(message = "Arguments are incompatible.")
   }
 
-
   cdf <- matrix(NA, nrow = nrow(q), ncol = 2)
   for (i in 1:2) {
     cdf[, i] <- 1 - exp(-q[, i] * rate[i])
   }
 
 
-
   if (!lower.tail) {
     cdf <- 1 - cdf
   }
 
-
   return(cdf)
 }
 #' @name Neutrosophic Exponential
 #' @examples
 #' # The first percentile
-#' qnsexp(p = 0.1, rate = 0.25)
+#' qnsExp(p = 0.1, rate = 0.25)
 #'
 #' # The quantiles
-#' qnsexp(p = c(0.25, 0.5, 0.75), rate = c(0.24, 0.25))
+#' qnsExp(p = c(0.25, 0.5, 0.75), rate = c(0.24, 0.25))
 #'
 #' @export
-qnsexp <- function(p, rate) {
+qnsExp <- function(p, rate) {
   if (any(p < 0) || any(p > 1)) {
     stop(message = "Warning: p should be in the interval [0,1].")
   }
@@ -130,23 +129,22 @@ qnsexp <- function(p, rate) {
     quantiles[, i] <- stats::qexp(p[, i], rate = rate[i])
   }
 
-
   return(quantiles)
 }
 
 #' @name Neutrosophic Exponential
 #' @examples
 #' # Simulate 10 numbers
-#' rnsexp(n = 10, rate = c(0.23, 0.24))
+#' rnsExp(n = 10, rate = c(0.23, 0.24))
 #' @export
 #'
-rnsexp <- function(n, rate) {
+rnsExp <- function(n, rate) {
   if (any(rate <= 0)) {
     stop(message = "Arguments are incompatible.")
   }
   rate <- rep(rate, length.out = 2)
 
-  X <- qnsexp(runif(n), rate)
+  X <- qnsExp(runif(n), rate)
   condition <- X[, 1] > X[, 2]
   X[condition, 1:2] <- X[condition, 2:1]
 
